@@ -1,9 +1,7 @@
 /* -*-c-*- -------------- mixgtk_gen_handlers.c :
  * Implementation of the functions declared in mixgtk_gen_handlers.h
  * ------------------------------------------------------------------
- * $Id: mixgtk_gen_handlers.c,v 1.10 2005/09/20 19:43:14 jao Exp $
- * ------------------------------------------------------------------
- * Copyright (C) 2001, 2002, 2004 Free Software Foundation, Inc.
+ * Copyright (C) 2001, 2002, 2004, 2006 Free Software Foundation, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,44 +25,73 @@
 #include "mixgtk_config.h"
 
 /* grab a file with an externally provided callback */
-void
-mixgtk_get_file (file_callback_t callback,
-		 const gchar *title,
-                 const gchar *pattern,
-                 const gchar *def_file)
+typedef void (*file_callback_t)(const gchar *file);
+
+static GtkFileChooser *
+get_chooser_ (const gchar *title, gboolean src)
 {
+  static GtkFileChooser *dialog = NULL;
+  static GtkFileFilter *src_filter = NULL;
+  static GtkFileFilter *code_filter = NULL;
+
+  if (dialog == NULL)
+    {
+      dialog = GTK_FILE_CHOOSER
+        (gtk_file_chooser_dialog_new ("gmixvm",
+                                      NULL,
+                                      GTK_FILE_CHOOSER_ACTION_OPEN,
+                                      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                                      GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+                                      NULL));
+      src_filter = gtk_file_filter_new ();
+      gtk_file_filter_add_pattern (src_filter, "*.mixal");
+      code_filter = gtk_file_filter_new ();
+      gtk_file_filter_add_pattern (code_filter, "*.mix");
+      gtk_file_chooser_add_filter (dialog, src_filter);
+      gtk_file_chooser_add_filter (dialog, code_filter);
+    }
+
+  gtk_file_chooser_set_filter (dialog, src? src_filter : code_filter);
+  gtk_window_set_title (GTK_WINDOW (dialog), title);
+
+  return dialog;
+}
+
+static void
+get_file_ (file_callback_t callback,
+           const gchar *title,
+           gboolean is_src,
+           const gchar *def_file)
+{
+  static gchar *last_folder = NULL;
+
   if (callback != NULL)
     {
-      GtkWidget *dialog;
-
-      dialog =
-        gtk_file_chooser_dialog_new (title,
-                                     NULL,
-                                     GTK_FILE_CHOOSER_ACTION_OPEN,
-                                     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                     GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
-                                     NULL);
-
-      if (pattern != NULL)
-        {
-          GtkFileFilter *filter = gtk_file_filter_new ();
-          gtk_file_filter_add_pattern (filter, pattern);
-          gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog), filter);
-        }
+      GtkFileChooser *dialog = get_chooser_ (title, is_src);
 
       if (def_file != NULL)
-        gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (dialog), def_file);
-
-      if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
         {
-          char *filename;
-
-          filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
-          callback (filename);
-          g_free (filename);
+          gtk_file_chooser_set_filename (dialog, def_file);
+        }
+      else if (last_folder != NULL)
+        {
+          gtk_file_chooser_set_current_folder (dialog, last_folder);
         }
 
-      gtk_widget_destroy (dialog);
+      gint result = gtk_dialog_run (GTK_DIALOG (dialog));
+      gtk_widget_hide (GTK_WIDGET (dialog));
+
+      if (result == GTK_RESPONSE_ACCEPT)
+        {
+          gchar *filename = gtk_file_chooser_get_filename (dialog);
+          if (filename)
+            {
+              callback (filename);
+              if (last_folder) g_free (last_folder);
+              last_folder = g_path_get_dirname (filename);
+              g_free (filename);
+            }
+        }
     }
 }
 
@@ -87,14 +114,13 @@ exec_cmd_ (mix_vm_command_t cmd, const gchar *arg)
 static void
 open_cb_ (const gchar *file)
 {
-  if (file)
-      exec_cmd_ (MIX_CMD_LOAD, file);
+  exec_cmd_ (MIX_CMD_LOAD, file);
 }
 
 void
 on_file_open_activate (GtkWidget *w, gpointer data)
 {
-  mixgtk_get_file (open_cb_, _("Load MIX program..."), "*.mix", NULL);
+  get_file_ (open_cb_, _("Load MIX program..."), FALSE, NULL);
 }
 
 /* edit mixal source */
@@ -107,8 +133,10 @@ edit_cb_ (const gchar *file)
 void
 on_file_edit_activate (GtkWidget *w, gpointer data)
 {
-  mixgtk_get_file (edit_cb_, _("Edit MIXAL source file..."), "*.mixal",
-		   mixgtk_cmd_dispatcher_get_src_path ());
+  get_file_ (edit_cb_,
+             _("Edit MIXAL source file..."),
+             TRUE,
+             mixgtk_cmd_dispatcher_get_src_path ());
 }
 
 /* compile mixal source */
@@ -121,8 +149,10 @@ compile_cb_ (const gchar *file)
 void
 on_file_compile_activate (GtkWidget *w, gpointer data)
 {
-  mixgtk_get_file (compile_cb_, _("Compile MIXAL source file..."), "*.mixal",
-		   mixgtk_cmd_dispatcher_get_src_path ());
+  get_file_ (compile_cb_,
+             _("Compile MIXAL source file..."),
+             TRUE,
+             mixgtk_cmd_dispatcher_get_src_path ());
 }
 
 void
