@@ -1,9 +1,7 @@
 /* -*-c-*- -------------- xmix_vm_handlers.c :
  * Implementation of the functions declared in xmix_vm_handlers.h
  * ------------------------------------------------------------------
- * $Id: xmix_vm_handlers.c,v 1.10 2005/09/20 19:43:13 jao Exp $
- * ------------------------------------------------------------------
- * Copyright (C) 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
+ * Copyright (C) 2001, 2002, 2003, 2004, 2006 Free Software Foundation, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -79,7 +77,7 @@ mix_vm_command_info_t commands_[] = {
   { "sbpo", cmd_sbpo_,
     N_("Set conditional breakpoint on overflow toggled"), "sbpo"},
   { "cbpo", cmd_cbpo_,
-    N_("Set conditional breakpoint on overflow toggled"), "cbpo"},
+    N_("Clear conditional breakpoint on overflow toggled"), "cbpo"},
   { "cabp", cmd_cabp_, N_("Clear all breakpoints"), "cabp"},
   { "weval", cmd_weval_, N_("Evaluate a given W-expression"), "weval WEXPR"},
   { "w2d", cmd_w2d_, N_("Convert a MIX word to its decimal value"),
@@ -665,6 +663,7 @@ cmd_smem_ (mix_vm_cmd_dispatcher_t *dis, const gchar *carg)
   glong value = 0;
   int k = 0;
   gchar *arg = NULL;
+  mix_word_t wval;
 
   if (ok)
     {
@@ -681,6 +680,12 @@ cmd_smem_ (mix_vm_cmd_dispatcher_t *dis, const gchar *carg)
 	{
 	  while (isspace (arg[k])) k++;
 	  value = atol (arg + k);
+
+          if ((value == 0) && (arg[k] == '-'))
+            wval = MIX_WORD_MINUS_ZERO;
+          else
+            wval = mix_word_new (value);
+
 	  if ( arg[k] == '+' || arg[k] == '-' ) k++;
 	  while (isdigit (arg[k])) k++;
 	  ok = arg[k] == '\0';
@@ -688,12 +693,14 @@ cmd_smem_ (mix_vm_cmd_dispatcher_t *dis, const gchar *carg)
     }
 
   if (ok)
-    mix_vm_set_addr_contents (dis->vm, mix_short_new (addr),
-			      mix_word_new (value));
+    {
+      mix_vm_set_addr_contents (dis->vm, mix_short_new (addr), wval);
+    }
   else
     {
       log_error_ (dis, _("Invalid argument: %s"), arg);
     }
+
   if (arg) g_free (arg);
 
   return ok;
